@@ -56,6 +56,13 @@ sub create {
 
 }
 
+sub console {
+    my $self = shift;
+    my $ctid = $vos->{name};
+    my $cmd = $util->find_bin( 'jexec', debug => 0 );
+    exec "$cmd $ctid su";
+};
+
 sub is_present {
     my $self = shift;
     my $homedir = $self->get_ve_home();
@@ -63,13 +70,6 @@ sub is_present {
     return;
 };
 
-sub get_console {
-    my $self = shift;
-    my $ctid = $vos->{name};
-    my $cmd = $util->find_bin( 'jexec', debug => 0 );
-    exec "$cmd $ctid su";
-};
-
 sub get_ve_home {
     my $self = shift;
     my $ctid = $vos->{name} || shift;
